Struct curve25519_dalek::backend::serial::curve_models::AffineNielsPoint [−][src]
pub struct AffineNielsPoint {
pub y_plus_x: FieldElement51,
pub y_minus_x: FieldElement51,
pub xy2d: FieldElement51,
}Expand description
A pre-computed point in the affine model for the curve, represented as \((y+x, y-x, 2dxy)\) in “Niels coordinates”.
More details on the relationships between the different curve models can be found in the module-level documentation.
Fields
y_plus_x: FieldElement51y_minus_x: FieldElement51xy2d: FieldElement51Trait Implementations
type Output = CompletedPoint
type Output = CompletedPoint
The resulting type after applying the + operator.
Performs the + operation. Read more
Returns the “default value” for a type. Read more
Returns the identity element of the curve. Can be used as a constructor. Read more
type Output = AffineNielsPoint
type Output = AffineNielsPoint
The resulting type after applying the - operator.
Performs the unary - operation. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
type Output = CompletedPoint
type Output = CompletedPoint
The resulting type after applying the - operator.
Performs the - operation. Read more